==> haskell-pango-0.13.3.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.3.1
id: pango-0.13.3.1-DdiEy2VVNooGJk86u4s9ub
key: pango-0.13.3.1-DdiEy2VVNooGJk86u4s9ub
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Font
    Graphics.Rendering.Pango.Enums Graphics.Rendering.Pango.Context
    Graphics.Rendering.Pango.Layout Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Types Graphics.Rendering.Pango.BasicTypes
    Graphics.Rendering.Pango.Structs
    Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 1b13188dead6fbcc87e5cd5379d8280c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pango-0.13.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pango-0.13.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/pango-0.13.3.1
hs-libraries: HSpango-0.13.3.1-DdiEy2VVNooGJk86u4s9ub
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/libdrm
includes:
    hspango.h
depends:
    array-0.5.1.1 base-4.9.0.0 cairo-0.13.3.1-B8SWhbrAJssFhnsoNQJ69I
    containers-0.5.7.1 directory-1.2.6.2
    glib-0.13.4.1-6JZW7jufw4hIaaKiUUOHkH
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pretty-1.1.3.3 process-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.3.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.3.1
id: pango-0.13.3.1-1NPDZjGegnjKCvlUKSv18q
key: pango-0.13.3.1-1NPDZjGegnjKCvlUKSv18q
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Font
    Graphics.Rendering.Pango.Enums Graphics.Rendering.Pango.Context
    Graphics.Rendering.Pango.Layout Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Types Graphics.Rendering.Pango.BasicTypes
    Graphics.Rendering.Pango.Structs
    Graphics.Rendering.Pango.Attributes
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
abi: 4f5e5855fbf0783f782fac52dbc92677
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pango-0.13.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pango-0.13.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/pango-0.13.3.1
hs-libraries: HSpango-0.13.3.1-1NPDZjGegnjKCvlUKSv18q
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/pango-1.0 /usr/include/cairo
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/libdrm
includes:
    hspango.h
depends:
    array-0.5.1.1 base-4.9.0.0 cairo-0.13.3.1-2aGPO8ZCviBEichAQxduNY
    containers-0.5.7.1 directory-1.2.6.2
    glib-0.13.4.1-EEQaey3pIjy8n9nCCarNfz
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pretty-1.1.3.3 process-1.4.2.0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
